Poultry
=======

.. image:: https://travis-ci.org/dimazest/poultry.png?branch=master
    :target: https://travis-ci.org/dimazest/poultry


.. image:: https://coveralls.io/repos/dimazest/poultry/badge.png?branch=master
    :target: https://coveralls.io/r/dimazest/poultry?branch=master

.. image:: https://requires.io/github/dimazest/poultry/requirements.png?branch=master
   :target: https://requires.io/github/dimazest/poultry/requirements/?branch=master
   :alt: Requirements Status

.. image:: https://pypip.in/v/poultry/badge.png
    :target: https://crate.io/packages/poultry/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/poultry/badge.png
    :target: https://crate.io/packages/poultry/
    :alt: Number of PyPI downloads


:documentation: http://poultry.readthedocs.org
:homepage: https://github.com/dimazest/poultry
:story: http://www.eecs.qmul.ac.uk/~dm303/a-story-behind-poultry-a-twitter-streaming-api-client.html
